@@ -560,7 +560,8 @@ def cli_parser():
     group1.add_argument('--store-dir', default=None, metavar='DIRECTORY',
         help='Save the artifacts in this directory, which must be empty or '
         'non-existent. Otherwise, the artifacts will be deleted and you only '
-        'see their hashes (if reproducible) or the diff output (if not).')
+        'see their hashes (if reproducible) or the diff output (if not). See '
+        'also --no-clean-on-error.')
     group1.add_argument('--variations', default="+all",
         help='Build variations to test as a comma-separated list of variation '
         'names. Default is "+all", equivalent to "%s", testing all available '
@@ -575,7 +576,7 @@ def cli_parser():
     group1_0.add_argument('--extra-build', metavar='VARIATIONS', default=[], action='append',
         help='Perform another build with the given VARIATIONS (which may be '
         'empty) to be applied on top of what was given for --variations and '
-        '--vary. Each occurence of this flag specifies another build, so e.g. '
+        '--vary. Each occurrence of this flag specifies another build, so e.g. '
         'given twice this will make reprotest perform 4 builds in total.')
     group1_0.add_argument('--auto-build', default=False, action='store_true',
         help='Automatically perform builds to try to determine which specific '
@@ -771,7 +772,8 @@ def run(argv, dry_run=None):
             source_pattern = values.source_pattern + (" " + source_pattern if source_pattern else "")
 
     # Variations args
-    specs = [get_main_spec(parsed_args)]
+    spec = get_main_spec(parsed_args)
+    specs = [spec]
     if parsed_args.auto_build:
         check_func = check_auto
     elif parsed_args.env_build:
